CREATE OR REPLACE PROCEDURE dumpfile_details (
  verzeichnis VARCHAR2 DEFAULT 'DATA_PUMP_DIR',
  dateiname VARCHAR2 DEFAULT 'EXPDAT.DMP')
AS
  v_dir all_directories.directory_path%type := '?';
  v_filetype NUMBER;
  v_info_table sys.ku$_dumpfile_info;
  type vartype IS VARRAY(23) OF VARCHAR2(2048);
  v_values vartype := vartype();
  v_dateiversion VARCHAR2(15);
BEGIN
  DBMS_OUTPUT.PUT_LINE('Verzeichnis: '||verzeichnis);
  DBMS_OUTPUT.PUT_LINE('Dateiname: '||dateiname);
  SELECT directory_path INTO v_dir FROM all_directories
  WHERE directory_name = verzeichnis OR directory_name = UPPER(verzeichnis);
  DBMS_OUTPUT.PUT_LINE('Pfad: '||v_dir);
  DBMS_DATAPUMP.GET_DUMPFILE_INFO(
  filename=>dateiname, directory=>UPPER(verzeichnis), info_table=>v_info_table, filetype=>v_filetype);
  v_values.EXTEND(23);
  FOR x IN 1 .. 23 LOOP
    BEGIN
      SELECT value INTO v_values(x) FROM TABLE(v_info_table)
      WHERE item_code = x;
    EXCEPTION WHEN OTHERS THEN v_values(x) := '';
    END;
  END LOOP;
  IF v_filetype = 1 THEN
    DBMS_OUTPUT.PUT_LINE('Dateityp: Data Pump Export');
    DBMS_OUTPUT.PUT_LINE('--------------------------------------------');
    BEGIN
      SELECT v_values(5) || ' (' || nls_charset_name(v_values(5)) || ')'
      INTO v_values(5) FROM dual;
    EXCEPTION WHEN OTHERS THEN null;
    END;
    SELECT SUBSTR(v_values(1), 1, 15) INTO v_dateiversion FROM dual;
    SELECT DECODE(v_values(1),
      '0.1', '0.1 (Oracle10g Release 1: 10.1.0.x)',
      '1.1', '1.1 (Oracle10g Release 2: 10.2.0.x)',
      '2.1', '2.1 (Oracle11g Release 1: 11.1.0.x)',
      '3.1', '3.1 (Oracle11g Release 2: 11.2.0.x)',
      '4.1', '4.1 (Oracle12c Release 1: 12.1.0.x)',
      v_values(1)) INTO v_values(1) FROM dual;
    SELECT DECODE(v_values(2), '0', '0 (Nein)', '1', '1 (Ja)',
      v_values(2)) INTO v_values(2) FROM dual;
    SELECT DECODE(v_values(14), '0', '0 (Nein)', '1', '1 (Ja)',
      v_values(14)) INTO v_values(14) FROM dual;
    SELECT DECODE(v_values(18), '0', '0 (Nein)', '1', '1 (Ja)',
      v_values(18)) INTO v_values(18) FROM dual;
    SELECT DECODE(v_values(19), '0', '0 (Nein)', '1', '1 (Ja)',
      v_values(19)) INTO v_values(19) FROM dual;
    SELECT DECODE(v_values(20), '0', '0 (Nein)', '1', '1 (Ja)',
      v_values(20)) INTO v_values(20) FROM dual;
    SELECT DECODE(v_values(21), '0', '0 (Nein)', '1', '1 (Ja)',
      v_values(21)) INTO v_values(21) FROM dual;
    SELECT DECODE(v_values(22),
      '1', '1 (Unknown)',
      '2', '2 (None)',
      '3', '3 (Password)',
      '4', '4 (Password and Wallet)',
      '5', '5 (Wallet)',
      v_values(22)) INTO v_values(22) FROM dual;
    SELECT DECODE(v_values(23),
      '2', '2 (None)',
      '3', '3 (Basic)',
      '4', '4 (Low)',
      '5', '5 (Medium)',
      '6', '6 (High)',
      v_values(23)) INTO v_values(23) FROM dual;
    DBMS_OUTPUT.PUT_LINE('Database Job-Version..........:' || v_values(15));
    DBMS_OUTPUT.PUT_LINE('Interne Dateiversion..........:' || v_values(1));
    DBMS_OUTPUT.PUT_LINE('Erstellungsdatum..............:' || v_values(6));
    DBMS_OUTPUT.PUT_LINE('Dateinummer im Set............:' || v_values(4));
    DBMS_OUTPUT.PUT_LINE('Master im Dumpfile............:' || v_values(2));
    DBMS_OUTPUT.PUT_LINE('Betriebssystem der Datenbank..:' || v_values(9));
    DBMS_OUTPUT.PUT_LINE('Zeichensatz der Datenbank.....:' || v_values(5));
    DBMS_OUTPUT.PUT_LINE('Sprache.......................:' || v_values(11));
    DBMS_OUTPUT.PUT_LINE('Jobname.......................:' || v_values(8));
    DBMS_OUTPUT.PUT_LINE('GUID..........................:' || v_values(3));
    DBMS_OUTPUT.PUT_LINE('Blockgröße der Datei (Bytes)..:' || v_values(12));
    DBMS_OUTPUT.PUT_LINE('Metadaten komprimiert.........:' || v_values(14));
    IF dbms_datapump.KU$_DFHDR_MAX_ITEM_CODE > 15 THEN
      DBMS_OUTPUT.PUT_LINE('Datenkomprimiert.............: ' || v_values(18));
      DBMS_OUTPUT.PUT_LINE('Metadatenverschüsselt........: ' || v_values(19));
      DBMS_OUTPUT.PUT_LINE('Tabellenverschlüsselt........: ' || v_values(20));
      DBMS_OUTPUT.PUT_LINE('Spaltenverschlüsselt.........: ' || v_values(21));
    END IF;
  ELSE
    DBMS_OUTPUT.PUT_LINE('Dateityp: Dateityp unbekannt');
  END IF;
END;
/
SET SERVEROUTPUT ON SIZE 1000000
BEGIN
dumpfile_details('EXP', 'ssb.dmp');
END;
/